# North Carolina Subsidized Child Care Assistance Program

The **childcare market rates** used in this program are sourced from the [Subsidized Child Care Market Rates for Child Care Centers - Effective 10-1-2023](https://ncchildcare.ncdhhs.gov/Portals/0/documents/pdf/M/Market_Rates_Centers_Eff_10-1.pdf?ver=9w52alSPhmrmo0N9gGVMEw%3d%3d) for 4-star Child Care Centers. Only facilities rated 3 stars or higher can [participate](https://ncchildcare.ncdhhs.gov/Whats-New/care-for-children-receiving-subsidy#:~:text=Providing%20Care%20for%20Children%20Receiving%20Subsidy%20To,must%20have%20a%20Notice%20of%20Compliance%20letter.) the NC SCCA program, with most subsidized children enrolled in centers rather than home facilities, according to the NC DHHS Division of Child Development and Early Education Child Care Analysis Summary. The 4-star center rate was selected as a representative average, as the highest enrollment by star rating varies by county. For school-age children (ages 6–12), the 4-star center market rate is reduced by 45% to account for their reduced child care hours, as estimated in the [Living Income Standard](https://ncbudget.org/2025-living-income-standard-methodology/) methodologiy developed by by the North Carolina Budget and Tax Center, which assumes school age children get care for about 45% of the time:  2.5 months during the summer and 1/3 of the day during the school year for before and/or after school.

**Note:** Market Rates do not update annually or on any regular schedule. NCDHHS will announce publicly, such as on its website, when it plans to update market rates. 